def to_lower_case(text_input: str) -> str:
    """Converting text to lowercase

    :param text_input: Input text to be processed.
    :type text_input: `str`
    :return: Text with all characters on lowercase.
    :rtype: `str`
    """
    return text_input.lower()
