ABBREVIATIONS = {"hj": "hoje",
                 "vc": "você",
                 "vcs": "vocês",
                 "aq": "aqui",
                 "eh": "é",
                 "cmg": "comigo",
                 "cm": "comigo",
                 "c": "com",
                 "iso": "isso",
                 "mto": "muito",
                 "mt": "muito",
                 "vo": "vou",
                 "p": "para",
                 "pq": "porque",
                 "q": "que",
                 "ñ": "não",
                 "n": "não",
                 "aki": "aqui",
                 "td": "tudo",
                 "blz": "beleza",
                 "ond": "onde",
                 "qndo": "quando",
                 "qnd": "quando",
                 "mnh": "minha",
                 "porq": "porque",
                 "qro": "quero",
                 "agr": "agora",
                 "cod": "código",
                 "codg": "código",
                 "n°": "número",
                 "pagto": "pagamento",
                 "vdd": "verdade",
                 "dps": "depois",
                 "ve": "ver",
                 "pfv": "por favor",
                 "pfvr": "por favor",
                 "av": "avenida",
                 "ap": "apartamento",
                 "tb": "também",
                 "tbm": "também",
                 "cc": "conta corrente",
                 "obg": "obrigado",
                 "obgd": "obrigado",
                 "obgdo": "obrigado",
                 "obgda": "obrigada",
                 "ctt": "contato",
                 "nn": "nao",
                 "qd": "quando",
                 "hr": "hora",
                 "fco": "faço",
                 "qro": "quero",
                 "qlq": "qualquer",
                 "d": "de",
                 "to": "estou",
                 "tô": "estou",
                 "tá": "está",
                 "ta": "está",
                 "msg": "mensagem",
                 "msgs": "mensagens",
                 "msgm": "mensagem",
                 "msgns": "mensagens",
                 "prq": "porque",
                 "vlr": "valor",
                 "qdo": "quando",
                 "apto": "apartamento",
                 "msm": "mesmo",
                 "msmo": "mesmo",
                 "msma": "mesma",
                 "eh": "é",
                 "neh": "né",
                 "itau": "Itaú",
                 "fasso": "faço",
                 "opicao": "opção",
                 "presciso": "preciso",
                 "è": "é",
                 "faser": "fazer",
                 "naõ": "não",
                 "tbem": "também",
                 "extorno": "estorno",
                 "presiso": "preciso",
                 "internete": "internet",
                 "adiquirir": "adquirir",
                 "chipe": "chip",
                 "imail": "email",
                 "e-mail": "email",
                 "tel": "telefone",
                 "poblema": "problema",
                 "whats": "whatsapp",
                 "oque": "o que",
                 "min": "minuto",
                 "tou": "estou",
                 "qto": "quanto",
                 "qtos": "quantos",
                 "qnto": "quanto",
                 "qntos": "quantos",
                 "qta": "quanta",
                 "qtas": "quantas",
                 "qntas": "quantas",
                 "pgto": "pagamento",
                 "pc": "computador",
                 "pq": "porque",
                 "p/": "para",
                 "c/": "com",
                 "br": "brasil",
                 "tv": "televisão",
                 "att": "atenciosamente",
                 "apt": "apartamento",
                 "obs": "observação",
                 "nd": "nada",
                 "aprox": "aproximadamente",
                 "qria": "queria",
                 "qero": "quero",
                 "tmb": "também",
                 "odonto": "odontologia",
                 "gov": "governo",
                 "smp": "sempre",
                 "amg": "amigo",
                 "tds": "todos",
                 "tdos": "todos",
                 "tdas": "todas",
                 "ngm": "ninguém",
                 "bjs": "beijos",
                 "bjos": "beijos",
                 "abç": "abraço",
                 "abçs": "abraços",
                 "num": "número",
                 "mi": "me",
                 "oq": "o que"
                 }
